OC.L10N.register(
    "lib",
    {
    "today" : "ਅੱਜ",
    "yesterday" : "ਕੱਲ੍ਹ",
    "last month" : "ਪਿਛਲੇ ਮਹੀਨੇ",
    "last year" : "ਪਿਛਲੇ ਸਾਲ",
    "seconds ago" : "ਸਕਿੰਟ ਪਹਿਲਾਂ",
    "Username" : "ਯੂਜ਼ਰ-ਨਾਂ",
    "Password" : "ਪਾਸਵਰ",
    "General" : "ਆਮ",
    "Sharing" : "ਸਾਂਝ",
    "Search" : "ਖੋਜ",
    "Help" : "ਮਦਦ",
    "Settings" : "ਸੈਟਿੰਗ",
    "Imprint" : "ਛਾਪ",
    "__language_name__" : "__ਭਾਸ਼ਾ_ਨਾਂ__"
},
"nplurals=2; plural=(n != 1);");
